@@ -31,33 +31,51 @@ import urllib2
 import pkg_resources
 from slapos.lib.recipe.BaseSlapRecipe import BaseSlapRecipe
 
-class Recipe(BaseSlapRecipe):
+class NoSQLTestBed(BaseSlapRecipe):
 
   def _install(self):
     self.parameter_dict = self.computer_partition.getInstanceParameterDict()
-    software_type = self.parameter_dict.get('slap_software_type', 'kumo_cloud')
+    software_type = self.parameter_dict.get('slap_software_type', 'default')
     if software_type is None or software_type == 'RootSoftwareInstance':
-      software_type = 'kumo_cloud'
+      software_type = 'default'
     if "run_%s" % software_type in dir(self) and \
        callable(getattr(self, "run_%s" % software_type)):
       return getattr(self, "run_%s" % software_type)()
     else:
       raise NotImplementedError("Do not support %s" % software_type)
 
+  def run_default(self):
+    return None
+
   def run_kumo_cloud(self):
-    """ """
+    """ Deploy kumofs systeom on a cloud. """
 
     kumo_cloud_config = {}
     kumo_cloud_config.update(self.options)
+    kumo_cloud_config.update(self.parameter_dict)
 
     kumo_cloud_config['address'] = self.getGlobalIPv6Address()
     kumo_cloud_config['report_path'] = self.log_directory
+    
+    if 'nb_server_max' not in kumo_cloud_config:
+      kumo_cloud_config['nb_server_max'] = 3
+    
+    if 'nb_tester_max' not in kumo_cloud_config:
+      kumo_cloud_config['nb_tester_max'] = 3
+    
+    if 'nb_thread' not in kumo_cloud_config:
+      kumo_cloud_config['nb_thread'] = 1
+    
+    if 'nb_request' not in kumo_cloud_config:
+      kumo_cloud_config['nb_request'] = 1000
+    
     kumo_cloud_config['software_release_url'] = self.software_release_url
     kumo_cloud_config['server_url'] = self.server_url
     kumo_cloud_config['key_file'] = self.key_file
     kumo_cloud_config['cert_file'] = self.cert_file
     kumo_cloud_config['computer_id'] = self.computer_id
     kumo_cloud_config['computer_partition_id'] = self.computer_partition_id
+    kumo_cloud_config['plugin_name'] = 'kumo'
 
     kumo_cloud_connection = {}
     kumo_cloud_connection['url'] = "http://["+kumo_cloud_config['address']+"]:5000/"
@@ -65,8 +83,8 @@ class Recipe(BaseSlapRecipe):
 
     nosqltester_manager_wrapper_template_location = pkg_resources.resource_filename(
                                              __name__, os.path.join(
-                                             'template', 'nosqltester_manager_run.in'))
-    nosqltester_manager_runner_path = self.createRunningWrapper("nosqltester_manager",
+                                             'template', 'kumotester_manager_run.in'))
+    nosqltester_manager_runner_path = self.createRunningWrapper("kumotester_manager",
           self.substituteTemplate(nosqltester_manager_wrapper_template_location, kumo_cloud_config))
 
     return [nosqltester_manager_runner_path]
@@ -181,7 +199,7 @@ class Recipe(BaseSlapRecipe):
 
     return [gateway_runner_path]
 
-  def run_kumo_tester_easy(self):
+  def run_kumo_tester(self):
     """ Runs the kumofs tester. """
     tester_config = {}
     tester_config.update(self.options)
@@ -193,7 +211,9 @@ class Recipe(BaseSlapRecipe):
     tester_config['report_path'] = self.log_directory
     tester_config['binary'] = tester_config['memstrike_binary'] + " -l " + \
                               tester_config['gateway_address'].strip("[]") + " -p " + \
-                              tester_config['gateway_port'] + " 1000" #" -t 32 1024000"
+                              tester_config['gateway_port'] + " -t " + \
+                              tester_config['nb_thread'] + " " + \
+                              tester_config['nb_request'] #" 1000" " -t 32 1024000"
 
     tester_connection = {}
     tester_connection['start_url'] = "http://%s:5000/start" % tester_config['tester_address']
